=======
History
=======

0.1.0 (2017-08-24)
------------------

* First release on PyPI.

0.2.0 (2018-12-20)
------------------

* Integrated changes from community: added monitoring of ouitputs.
* Attempt at fixing issue with "state unknown" of the alarm. Unfurtunately unsuccesful.